@@ -1,4 +1,4 @@
-## Copyright (C) 2016 Julien Bect <jbect@users.sourceforge.net>
+## Copyright (C) 2016, 2017 Julien Bect <jbect@users.sourceforge.net>
 ## Copyright (C) 2016 Susi Lehtola
 ## Copyright (C) 2004 Teemu Ikonen <tpikonen@pcu.helsinki.fi>
 ##
@@ -806,40 +806,6 @@ export octave_name=lncosh
 export    funcname=gsl_sf_lncosh_e
 ${RT} D_D >> gsl_sf.cc
 
-######################################################################
-
-export octave_name=gsl_zt_zeta
-export    funcname=gsl_sf_zeta_e
-cat << \EOF > docstring.txt
-Computes the Riemann zeta function \zeta(s) for
-arbitrary s, s \ne 1.
-
-The Riemann zeta function is defined by the infinite sum
-\zeta(s) = \sum_@{k=1@}^\infty k^@{-s@}.
-EOF
-${RT} D_D >> gsl_sf.cc
-
-## Deprecated naming scheme
-export octave_name=zeta
-export    funcname=gsl_sf_zeta_e
-${RT} D_D >> gsl_sf.cc
-
-######################################################################
-
-export octave_name=gsl_sf_eta
-export    funcname=gsl_sf_eta_e
-cat << \EOF > docstring.txt
-Computes the eta function \eta(s) for arbitrary s.
-
-The eta function is defined by \eta(s) = (1-2^@{1-s@}) \zeta(s).
-EOF
-${RT} D_D >> gsl_sf.cc
-
-## Deprecated naming scheme
-export octave_name=eta
-export    funcname=gsl_sf_eta_e
-${RT} D_D >> gsl_sf.cc
-
 
 # (int, double) to double ############################################
 
@@ -1442,22 +1408,6 @@ export octave_name=conicalP_1
 export    funcname=gsl_sf_conicalP_1_e
 ${RT} DD_D >> gsl_sf.cc
 
-######################################################################
-
-export octave_name=gsl_sf_hzeta
-export    funcname=gsl_sf_hzeta_e
-cat << \EOF > docstring.txt
-Computes the Hurwitz zeta function \zeta(s,q)
-for s > 1, q > 0.
-EOF
-${RT} DD_D >> gsl_sf.cc
-
-## Deprecated naming scheme
-export octave_name=hzeta
-export    funcname=gsl_sf_hzeta_e
-${RT} DD_D >> gsl_sf.cc
-
-
 
 # (double, mode) to double ###########################################
 
@@ -1924,35 +1874,6 @@ export octave_name=psi_1_int
 export    funcname=gsl_sf_psi_1_int_e
 ${RT} I_D >> gsl_sf.cc
 
-######################################################################
-
-export octave_name=gsl_sf_zeta_int
-export    funcname=gsl_sf_zeta_int_e
-cat << \EOF > docstring.txt
-Computes the Riemann zeta function \zeta(n) for
-integer n, n \ne 1.
-EOF
-${RT} I_D >> gsl_sf.cc
-
-## Deprecated naming scheme
-export octave_name=zeta_int
-export    funcname=gsl_sf_zeta_int_e
-${RT} I_D >> gsl_sf.cc
-
-######################################################################
-
-export octave_name=gsl_sf_eta_int
-export    funcname=gsl_sf_eta_int_e
-cat << \EOF > docstring.txt
-Computes the eta function \eta(n) for integer n.
-EOF
-${RT} I_D >> gsl_sf.cc
-
-## Deprecated naming scheme
-export octave_name=eta_int
-export    funcname=gsl_sf_eta_int_e
-${RT} I_D >> gsl_sf.cc
-
 
 # (int, double, double) to double ####################################
 
@@ -2623,3 +2544,113 @@ Condon-Shortley phase factor of (-1)^m, set the fourth parameter to
 either -1 or 1, respectively.
 EOF
 ${RT} NSDD_DDD_array >> gsl_sf.cc
+
+
+######################################################################
+##                   Zeta and related functions                     ##
+######################################################################
+
+
+## Riemann zeta function
+
+export octave_name=gsl_sf_zeta
+export    funcname=gsl_sf_zeta_e
+cat << \EOF > docstring.txt
+Computes the Riemann zeta function \zeta(s) for
+arbitrary s, s \ne 1.
+
+The Riemann zeta function is defined by the infinite sum
+\zeta(s) = \sum_@{k=1@}^\infty k^@{-s@}.
+EOF
+${RT} D_D >> gsl_sf.cc
+
+## Deprecated naming scheme (package release 2.0.0)
+export octave_name=gsl_zt_zeta
+export    funcname=gsl_sf_zeta_e
+${RT} D_D >> gsl_sf.cc
+
+## Deprecated naming scheme (package release < 2.0.0)
+export octave_name=zeta
+export    funcname=gsl_sf_zeta_e
+${RT} D_D >> gsl_sf.cc
+
+export octave_name=gsl_sf_zeta_int
+export    funcname=gsl_sf_zeta_int_e
+cat << \EOF > docstring.txt
+Computes the Riemann zeta function \zeta(n) for
+integer n, n \ne 1.
+EOF
+${RT} I_D >> gsl_sf.cc
+
+## Deprecated naming scheme (package release < 2.0.0)
+export octave_name=zeta_int
+export    funcname=gsl_sf_zeta_int_e
+${RT} I_D >> gsl_sf.cc
+
+
+## Riemann zeta function minus one
+
+export octave_name=gsl_sf_zetam1
+export    funcname=gsl_sf_zetam1_e
+cat << \EOF > docstring.txt
+Computes \zeta(s) - 1 for arbitrary s, s \ne 1, where \zeta
+denotes the Riemann zeta function.
+
+@seealso{gsl_sf_zeta}
+EOF
+${RT} D_D >> gsl_sf.cc
+
+export octave_name=gsl_sf_zetam1_int
+export    funcname=gsl_sf_zetam1_int_e
+cat << \EOF > docstring.txt
+Computes \zeta(s) - 1 for integer n, n \ne 1, where \zeta
+denotes the Riemann zeta function.
+
+@seealso{gsl_sf_zetam1, gsl_sf_zeta, gsl_sf_zeta_int}
+EOF
+${RT} I_D >> gsl_sf.cc
+
+
+## Dirichlet eta function 
+
+export octave_name=gsl_sf_eta
+export    funcname=gsl_sf_eta_e
+cat << \EOF > docstring.txt
+Computes the eta function \eta(s) for arbitrary s.
+
+The eta function is defined by \eta(s) = (1-2^@{1-s@}) \zeta
+EOF
+${RT} D_D >> gsl_sf.cc
+
+## Deprecated naming scheme
+export octave_name=eta
+export    funcname=gsl_sf_eta_e
+${RT} D_D >> gsl_sf.cc
+
+export octave_name=gsl_sf_eta_int
+export    funcname=gsl_sf_eta_int_e
+cat << \EOF > docstring.txt
+Computes the eta function \eta(n) for integer n.
+EOF
+${RT} I_D >> gsl_sf.cc
+
+## Deprecated naming scheme
+export octave_name=eta_int
+export    funcname=gsl_sf_eta_int_e
+${RT} I_D >> gsl_sf.cc
+
+
+## Hurwitz zeta function
+
+export octave_name=gsl_sf_hzeta
+export    funcname=gsl_sf_hzeta_e
+cat << \EOF > docstring.txt
+Computes the Hurwitz zeta function \zeta(s,q)
+for s > 1, q > 0.
+EOF
+${RT} DD_D >> gsl_sf.cc
+
+## Deprecated naming scheme
+export octave_name=hzeta
+export    funcname=gsl_sf_hzeta_e
+${RT} DD_D >> gsl_sf.cc
